[Bf-blender-cvs] [a349a3a] master: UI: Show edge draw options for duplis, it applied to their instances

Campbell Barton noreply at git.blender.org
Thu Mar 13 16:15:33 CET 2014


Commit: a349a3a94ecf6413f2ef62c872fdefda010df597
Author: Campbell Barton
Date:   Fri Mar 14 02:13:31 2014 +1100
https://developer.blender.org/rBa349a3a94ecf6413f2ef62c872fdefda010df597

UI: Show edge draw options for duplis, it applied to their instances

===================================================================

M	release/scripts/startup/bl_ui/properties_object.py

===================================================================

diff --git a/release/scripts/startup/bl_ui/properties_object.py b/release/scripts/startup/bl_ui/properties_object.py
index 8d7f5cf..b0872f4 100644
--- a/release/scripts/startup/bl_ui/properties_object.py
+++ b/release/scripts/startup/bl_ui/properties_object.py
@@ -207,16 +207,18 @@ class OBJECT_PT_display(ObjectButtonsPanel, Panel):
         obj_type = obj.type
         is_geometry = (obj_type in {'MESH', 'CURVE', 'SURFACE', 'META', 'FONT'})
         is_empty_image = (obj_type == 'EMPTY' and obj.empty_draw_type == 'IMAGE')
+        is_dupli = (obj.dupli_type != 'NONE')
 
         split = layout.split()
 
         col = split.column()
         col.prop(obj, "show_name", text="Name")
         col.prop(obj, "show_axis", text="Axis")
-        if is_geometry:
-            # Makes no sense for cameras, armatures, etc.!
+        # Makes no sense for cameras, armatures, etc.!
+        # but these settings do apply to dupli instances
+        if is_geometry or is_dupli:
             col.prop(obj, "show_wire", text="Wire")
-        if obj_type == 'MESH':
+        if obj_type == 'MESH' or is_dupli:
             col.prop(obj, "show_all_edges")
 
         col = split.column()




More information about the Bf-blender-cvs mailing list